camelot.camelot.model.authentication.PartyRelationship

Package camelot :: Package camelot :: Package model :: Module authentication :: Class PartyRelationship |
[hide private]
[frames] | no frames]

# Class PartyRelationship

source code

Class Variables | [hide private]
| from_date = `Field(Date(), default= datetime.date.today, requir`...``
| thru_date = `Field(Date(), default= end_of_times, required= Tru`...``
| comment = `Field(Text)`

Class Variable Details | [hide private]

  ### from_date Value:
      Field(Date(), default= datetime.date.today, required= True, index= Tru
      e)

  ### thru_date Value:
      Field(Date(), default= end_of_times, required= True, index= True)